==> 0.0.41.tar.gz: lib/src/widgets/form_factory/rich_text_form.dart <==
import 'package:flutter_markdown/flutter_markdown.dart';
import "package:flutter/material.dart";
import 'package:verttice_ui/verttice_ui.dart';

class RichTextFormFactory extends StatefulWidget {
  final String displayName;
  final String name;
  final dynamic value;
  final Function(String name, dynamic value) onChanged;
  final FormFieldState<dynamic>? state;

  const RichTextFormFactory({
    Key? key,
    required this.displayName,
    required this.name,
    required this.onChanged,
    this.state,
    this.value,
  }) : super(key: key);
  @override
  _TextFormState createState() => _TextFormState();
}

class _TextFormState extends State<RichTextFormFactory> {
  String _value = "";

  @override
  void initState() {
    super.initState();
    _value = widget.value;
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  void didUpdateWidget(covariant RichTextFormFactory oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_value != widget.value) {
      _value = widget.value;
    }
  }

  @override
  Widget build(BuildContext context) {
    return BorderLabel(
      label: widget.displayName,
      onPressed: () async {
        await fullPageDialog(
            context: context,
            builder: (BuildContext context) => Builder(builder: (context) {
                  return Scaffold(
                    appBar: const ThemedAppBar(),
                    body: ThemedEditor(
                      markdown: _value,
                      fileContentCallback: ({
                        required String fileContent,
                      }) async {
                        setState(() {
                          _value = fileContent;
                        });
                        widget.onChanged(widget.name, fileContent);
                        widget.state?.didChange(fileContent);
                        Navigator.pop(context);
                      },
                    ),
                  );
                }));
      },
      child: LayoutBuilder(builder: (context, constraints) {
        return SizedBox(
          width: constraints.maxWidth,
          child: Tooltip(
            message: _value,
            child: Markdown(
              data: _value,
            ),
          ),
        );
      }),
    );
  }
}

==> 0.0.51.tar.gz: lib/src/widgets/form_factory/rich_text_form.dart <==
import 'dart:convert';
import "package:flutter/material.dart";
import 'package:validators/validators.dart';
import 'package:verttice_ui/src/widgets/themed_editor/themed_editor.dart';
import 'package:verttice_ui/verttice_ui.dart';

class RichTextFormFactory extends StatefulWidget {
  final String displayName;
  final String name;
  final dynamic value;
  final Function(String name, dynamic value) onChanged;
  final FormFieldState<dynamic>? state;

  const RichTextFormFactory({
    Key? key,
    required this.displayName,
    required this.name,
    required this.onChanged,
    this.state,
    this.value,
  }) : super(key: key);
  @override
  _TextFormState createState() => _TextFormState();
}

class _TextFormState extends State<RichTextFormFactory> {
  String _value = "";

  @override
  void initState() {
    super.initState();
    _value = widget.value;
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  void didUpdateWidget(covariant RichTextFormFactory oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_value != widget.value) {
      _value = widget.value;
    }
  }

  @override
  Widget build(BuildContext context) {
    return BorderLabel(
      label: widget.displayName,
      onPressed: () async {
        await fullPageDialog(
            context: context,
            builder: (BuildContext context) => Builder(builder: (context) {
                  return Scaffold(
                    appBar: const ThemedAppBar(),
                    body: ThemedEditor(
                      jsonContect: isJSON(_value) ? json.decode(_value) : null,
                      fileContentCallback: ({
                        required List<dynamic> jsonContect,
                      }) async {
                        setState(() {
                          _value = json.encode(jsonContect);
                        });
                        widget.onChanged(widget.name, jsonContect);
                        widget.state?.didChange(jsonContect);
                        Navigator.pop(context);
                      },
                    ),
                  );
                }));
      },
      child: ThemedEditor(
        jsonContect: isJSON(_value) ? json.decode(_value) : null,
        readonly: true,
      ),
    );
  }
}
